==> 0.1.31.tar.gz: lib/src/cloud_models/cloud_connected_tool_status_recommendation.dart <==
import 'package:json_annotation/json_annotation.dart';

part 'cloud_connected_tool_status_recommendation.g.dart';

@JsonSerializable(explicitToJson: true)
class CloudConnectedToolStatusRecommendation {
  String? pluginId;
  String? pluginName;
  String? name;
  String? description;
  String? recommendationId;
  int? minValue;
  int? maxValue;
  String? valueType;
  int? flag;
  List<String>? threatsImpact;
  String? geigerValue;

  CloudConnectedToolStatusRecommendation({
    this.pluginId,
    this.pluginName,
    this.name,
    this.description,
    this.recommendationId,
    this.minValue,
    this.maxValue,
    this.valueType,
    this.flag,
    this.threatsImpact,
    this.geigerValue
  });

  factory CloudConnectedToolStatusRecommendation.fromJson(Map<String,dynamic> json) => _$CloudConnectedToolStatusRecommendationFromJson(json);

  Map<String, dynamic> toJson() => _$CloudConnectedToolStatusRecommendationToJson(this);

  String? get getPluginId => pluginId;
  set setPluginId(String pluginId) => this.pluginId = pluginId;

  String? get getPluginName => pluginName;
  set setPluginName(String pluginName) => this.pluginName = pluginName;

  String? get getName => name;
  set setName(String name) => this.name = name;

  String? get getDescription => description;
  set setDescription(String description) => this.description = description;

  String? get getRecommendationId => recommendationId;
  set setRecommendationId(String recommendationId) => this.recommendationId = recommendationId;

  int? get getMinValue => minValue;
  set setMinValue(int value) => this.minValue = value;

  int? get getMaxValue => maxValue;
  set setMaxValue(int value) => this.maxValue = value;

  String? get getValueType => valueType;
  set setValueType(String valueType) => this.valueType = valueType;

  int? get getFlag => flag;
  set setFlag(int flag) => this.flag = flag;

  List<String>? get getThreatsImpact => threatsImpact;
  set setThreatsImpact(List<String> values) => this.threatsImpact = values;

  String? get getGeigerValue => geigerValue;
  set setGeigerValue(String geigerValue) => this.geigerValue = geigerValue;

}

==> 0.1.36.tar.gz: lib/src/cloud_models/cloud_connected_tool_status_recommendation.dart <==
import 'package:json_annotation/json_annotation.dart';

part 'cloud_connected_tool_status_recommendation.g.dart';

@JsonSerializable(explicitToJson: true)
class CloudConnectedToolStatusRecommendation {
  String? pluginId;
  String? pluginName;
  String? name;
  String? description;
  String? recommendationId;
  int? minValue;
  int? maxValue;
  String? valueType;
  int? flag;
  String? threatsImpact;
  String? geigerValue;

  CloudConnectedToolStatusRecommendation({
    this.pluginId,
    this.pluginName,
    this.name,
    this.description,
    this.recommendationId,
    this.minValue,
    this.maxValue,
    this.valueType,
    this.flag,
    this.threatsImpact,
    this.geigerValue
  });

  factory CloudConnectedToolStatusRecommendation.fromJson(Map<String,dynamic> json) => _$CloudConnectedToolStatusRecommendationFromJson(json);

  Map<String, dynamic> toJson() => _$CloudConnectedToolStatusRecommendationToJson(this);

  String? get getPluginId => pluginId;
  set setPluginId(String pluginId) => this.pluginId = pluginId;

  String? get getPluginName => pluginName;
  set setPluginName(String pluginName) => this.pluginName = pluginName;

  String? get getName => name;
  set setName(String name) => this.name = name;

  String? get getDescription => description;
  set setDescription(String description) => this.description = description;

  String? get getRecommendationId => recommendationId;
  set setRecommendationId(String recommendationId) => this.recommendationId = recommendationId;

  int? get getMinValue => minValue;
  set setMinValue(int value) => this.minValue = value;

  int? get getMaxValue => maxValue;
  set setMaxValue(int value) => this.maxValue = value;

  String? get getValueType => valueType;
  set setValueType(String valueType) => this.valueType = valueType;

  int? get getFlag => flag;
  set setFlag(int flag) => this.flag = flag;

  String? get getThreatsImpact => threatsImpact;
  set setThreatsImpact(String values) => this.threatsImpact = values;

  String? get getGeigerValue => geigerValue;
  set setGeigerValue(String geigerValue) => this.geigerValue = geigerValue;

}
